#!/usr/bin/env node
import { McpServer } from "@modelcontextprotocol/sdk/server/mcp.js";
import { StdioServerTransport } from "@modelcontextprotocol/sdk/server/stdio.js";
import { z } from "zod";

// 创建MCP服务器
const server = new McpServer({
  name: "mcp-test-server",
  version: "0.0.1",
});


// 城市ID映射表（部分常用城市）
const CITY_MAP = {
  北京: "101010100",
  上海: "101020100",
  武汉: "101200101",
};

// Check for API key
const DASHSCOPE_API_KEY = process.env.DASHSCOPE_API_KEY;
if (!DASHSCOPE_API_KEY) {
  console.error("Error: DASHSCOPE_API_KEY environment variable is required");
  process.exit(1);
}

// 注册火车票
server.tool(
  "query_train_ticket",
  {
    from: z.string().describe("出发地"),
    to: z.string().describe("目的地"),
    time: z.string().describe("时间段"),
  },
  async ({ from, to, time }) => {
    return {
      content: [{
        type: "text",
        text: `火车票查询结果: ${from}到${to}的火车票，时间为${time}`,
      }],
    };
  }
);

async function runServer() {
  const transport = new StdioServerTransport();
  await server.connect(transport);
  console.error("Bailian Mcp Workflow Server running on stdio");
}

runServer().catch((error) => {
  console.error("Fatal error running server:", error);
  process.exit(1);
});
